/*
 * Error.c - Functions for displaying message boxes about various types of
 *	run-time errors.
 *
 *	ErrorAPI
 *	ErrorBox
 *
 * Copyright 2002 William R. Swanson
 * site@swansontec.com
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "Main.h"
#include <string.h>

/******************************************************************************
 * ErrorAPI - Displays a message box about the most recent Windows API error.
 */

void ErrorAPI (char szTitle[])
{
	DWORD		dwError;
	static char	szMsg [M_ERR_API_BUF] = M_ERR_API_MSG;

	/*
	 * Get a descriptive error string from the system, and append it to
	 *	the end of our message's text. If a descriptive string is not
	 *	available, use a generic one:
	 */
	if((dwError = GetLastError()) != ERROR_SUCCESS)
		FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM,
			NULL,
			dwError,
			LANG_SYSTEM_DEFAULT,
			szMsg + M_ERR_API_LEN,
			M_ERR_API_BUF - M_ERR_API_LEN,
			NULL);
	else
		strcat(szMsg, M_ERR_API_GEN);
	MessageBox(NULL, szMsg, szTitle, MB_OK | MB_ICONERROR);

	#ifdef _DEBUG
	OutputDebugString("szTitle");
	#endif
}

/******************************************************************************
 * ErrorBox - Displays a generic error message box.
 */

void ErrorBox (char szTitle[], char szError[])
{
	MessageBox(NULL, szError, szTitle, MB_OK | MB_ICONERROR);

	#ifdef _DEBUG
	OutputDebugString("szTitle");
	#endif
}